/*
 * A memory card region accessor.
 *
 * Copyright (C) 2021, 2024 Paul Boddie <paul@boddie.org.uk>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */

#pragma once

#include <stdio.h>

#include <fsserver/accessor.h>

#include "msc_region_operations.h"



/* A memory card region accessor, providing flexpages corresponding to the
   regions within an exposed memory card region or partition. */

class MscRegionAccessor : public Accessor
{
protected:
    MscRegionOperations *_ops;
    uint32_t _start;
    offset_t _size;

    /* Data transfer helper methods. */

    virtual void fill_populated(Flexpage *flexpage);

    virtual void flush_populated(Flexpage *flexpage);

public:
    explicit MscRegionAccessor(MscRegionOperations *ops, uint32_t start_block,
                               uint32_t num_blocks, fileid_t fileid);

    virtual offset_t get_size();

    virtual void set_size(offset_t size);
};

// vim: tabstop=4 expandtab shiftwidth=4
